@@ -41,7 +41,7 @@ class SquareNetTextTask:
         """
         if sleep_time < 5:
             raise ValueError(
-                f"Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}"
+                f"Param `sleep_time` must be greater than 5. U set - {sleep_time}"
             )
         self.sleep_time = sleep_time
         # проверяем переданный параметр способа сохранения капчи
@@ -165,7 +165,7 @@ class SquareNetTextTask:
         image_link: str = None,
         image_file: str = None,
         image_base64: str = None,
-    ):
+    ) -> dict:
         """
         Этот тип задачи берет вашу картинку, добавляет на нее сетку нужного размера и отдает работнику с требованием выбрать объекты нужного типа.
         :param objectName: Имя объекта.
@@ -257,7 +257,7 @@ class aioSquareNetTextTask:
         """
         if sleep_time < 5:
             raise ValueError(
-                f"Параметр `sleep_time` должен быть не менее 5. Вы передали - {sleep_time}"
+                f"Param `sleep_time` must be greater than 5. U set - {sleep_time}"
             )
         self.sleep_time = sleep_time
         # проверяем переданный параметр способа сохранения капчи
@@ -265,8 +265,6 @@ class aioSquareNetTextTask:
             self.save_format = save_format
         else:
             raise ValueError(
-                "\nПередан неверный формат сохранения файла изображения. "
-                f"\n\tВозможные варинты: `temp` и `const`. Вы передали - `{save_format}`"
                 "\nWrong `save_format` parameter. Valid params: `const` or `temp`."
                 f"\n\tYour param - `{save_format}`"
             )
@@ -301,7 +299,7 @@ class aioSquareNetTextTask:
         # Скачиваем капчу
         async with aiohttp.ClientSession() as session:
             async with session.get(captcha_link) as resp:
-                content = await resp.content.readany()
+                content = await resp.content.read()
                 # Создаём пайлоад, вводим ключ от сайта, выбираем метод ПОСТ и ждём ответа в JSON-формате
                 self.task_payload["task"].update(
                     {"body": base64.b64encode(content).decode("utf-8")}
@@ -325,7 +323,7 @@ class aioSquareNetTextTask:
         # Скачиваем капчу
         async with aiohttp.ClientSession() as session:
             async with session.get(captcha_link) as resp:
-                content = await resp.content.readany()
+                content = await resp.content.read()
 
         # Высчитываем хэш изображения, для того что бы сохранить его под уникальным именем
         image_hash = hashlib.sha224(content).hexdigest()
@@ -375,8 +373,6 @@ class aioSquareNetTextTask:
                 self.task_payload["task"].update({"body": content})
             else:
                 raise ValueError(
-                    "\nПередан неверный формат файла."
-                    f"\n\tВозможные варинты: `file` и `base64`. Вы передали - `{content_type}`"
                     f"\nWrong `content_type` parameter. Valid params: `file` or `base64`."
                     f"\n\tYour param - `{content_type}`"
                 )
@@ -397,7 +393,7 @@ class aioSquareNetTextTask:
         image_link: str = None,
         image_file: str = None,
         image_base64: str = None,
-    ):
+    ) -> dict:
         """
         Этот тип задачи берет вашу картинку, добавляет на нее сетку нужного размера и отдает работнику с требованием выбрать объекты нужного типа.
         :param objectName: Имя объекта.
